@@ -19,7 +19,6 @@
 
 #include "listjob.h"
 
-#include <boost/bind.hpp>
 #include <QtCore/QTimer>
 #include <KLocalizedString>
 
@@ -215,7 +214,7 @@ void ListJob::convertInboxName(KIMAP::MailBoxDescriptor &descriptor)
     if (!pathParts.isEmpty() &&
             pathParts[0].compare(QLatin1String("INBOX"), Qt::CaseInsensitive) == 0) {
         pathParts.removeAt(0);
-        descriptor.name = QLatin1String("INBOX");
+        descriptor.name = QStringLiteral("INBOX");
         if (!pathParts.isEmpty()) {
             descriptor.name += descriptor.separator + pathParts.join(descriptor.separator);
         }
