@@ -19,6 +19,7 @@
 
 #include "setmetadatajob.h"
 
+#include <KLocalizedString>
 #include "kimap_debug.h"
 
 #include "metadatajobbase_p.h"
@@ -26,7 +27,7 @@
 #include "session_p.h"
 #include "rfccodecs.h"
 
-namespace KIMAP2
+namespace KIMAP
 {
 class SetMetaDataJobPrivate : public MetaDataJobBasePrivate
 {
@@ -42,10 +43,10 @@ public:
 };
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 SetMetaDataJob::SetMetaDataJob(Session *session)
-    : MetaDataJobBase(*new SetMetaDataJobPrivate(session, "SetMetaData"))
+    : MetaDataJobBase(*new SetMetaDataJobPrivate(session, i18n("SetMetaData")))
 {
 }
 
@@ -57,7 +58,7 @@ void SetMetaDataJob::doStart()
 {
     Q_D(SetMetaDataJob);
     QByteArray parameters;
-    parameters = '\"' + KIMAP2::encodeImapFolderName(d->mailBox.toUtf8()) + "\" ";
+    parameters = '\"' + KIMAP::encodeImapFolderName(d->mailBox.toUtf8()) + "\" ";
     d->entriesIt = d->entries.constBegin();
 
     QByteArray command = "SETMETADATA";
@@ -101,8 +102,8 @@ void SetMetaDataJob::doStart()
         parameters += ')';
     }
 
-    d->sendCommand(command, parameters);
-//   qCDebug(KIMAP2_LOG) << "SENT: " << command << " " << parameters;
+    d->tags << d->sessionInternal()->sendCommand(command, parameters);
+//   qCDebug(KIMAP_LOG) << "SENT: " << command << " " << parameters;
 }
 
 void SetMetaDataJob::handleResponse(const Message &response)
@@ -114,7 +115,7 @@ void SetMetaDataJob::handleResponse(const Message &response)
         d->tags.contains(response.content.first().toString())) {
         if (response.content[1].toString() == "NO") {
             setError(UserDefinedError);
-            setErrorText(QString("%1 failed, server replied: %2").arg(d->m_name).arg(QLatin1String(response.toString().constData())));
+            setErrorText(i18n("%1 failed, server replied: %2", d->m_name, QLatin1String(response.toString().constData())));
             if (response.content[2].toString() == "[ANNOTATEMORE TOOMANY]" ||
                     response.content[2].toString() == "[METADATA TOOMANY]") {
                 d->metaDataErrors |= TooMany;
@@ -132,10 +133,10 @@ void SetMetaDataJob::handleResponse(const Message &response)
                 d->metaDataErrors |= NoPrivate;
             }
         } else if (response.content.size() < 2) {
-            setErrorText(QString("%1 failed, malformed reply from the server.").arg(d->m_name));
+            setErrorText(i18n("%1 failed, malformed reply from the server.", d->m_name));
         } else if (response.content[1].toString() != "OK") {
             setError(UserDefinedError);
-            setErrorText(QString("%1 failed, server replied: %2").arg(d->m_name).arg(QLatin1String(response.toString().constData())));
+            setErrorText(i18n("%1 failed, server replied: %2", d->m_name, QLatin1String(response.toString().constData())));
         }
         emitResult();
     } else if (d->serverCapability == Metadata && response.content[0].toString() == "+") {
@@ -153,7 +154,7 @@ void SetMetaDataJob::handleResponse(const Message &response)
             int size = d->entriesIt.value().size();
             content += " {" + QByteArray::number( size==0 ? 3 : size ) + '}';
         }
-//      qCDebug(KIMAP2_LOG) << "SENT: " << content;
+//      qCDebug(KIMAP_LOG) << "SENT: " << content;
         d->sessionInternal()->sendData(content);
     }
 }
